@@ -132,6 +132,8 @@ class RESTModel(object):
             payload = None
             if params:
                 payload = json_parser.dumps(params)
+            if not payload:
+                payload = json_parser.dumps({})
             # Make the request
             success = False
             json = send_request(action, url, data=payload)
@@ -217,4 +219,4 @@ class RESTModel(object):
         attributes = {}
         for attr in [attr for attr in vars(self) if not attr.startswith('_')]:
             attributes[attr] = getattr(self, attr, None)
-        return attributes
\ No newline at end of file
+        return attributes
